<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sagace_enqueue_scripts')) {

	function sagace_enqueue_scripts() {

		wp_deregister_style( 'avventura-lite-style' );
		wp_deregister_style( 'avventura-lite-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) );

		wp_enqueue_style( 'avventura-lite-parent-style' , get_template_directory_uri() . '/style.css' ); 

		wp_enqueue_style(
			'sagace-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) . '.css',
			array( 'sagace-style' ),
			'1.0.0'
		); 

		wp_enqueue_style( 'sagace-style' , get_stylesheet_directory_uri() . '/style.css' ); 

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Merriweather:300,300i,400,400i,700,700i,900,900i'),
			'subset' =>	'latin,latin-ext'
		);
		
		wp_deregister_style('google-fonts');
		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

		wp_enqueue_script(
			'sagace-script',
			get_stylesheet_directory_uri() . '/assets/js/script.js',
			array('jquery'),
			'1.0.0', 
			TRUE
		);

	}
	
	add_action( 'wp_enqueue_scripts', 'sagace_enqueue_scripts', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sagace_replace_hooks')) {

	function sagace_replace_hooks() {

		remove_action('avventura_lite_before_content', 'avventura_lite_before_content_function');
		remove_action('avventura_lite_after_content', 'avventura_lite_after_content_function');
		remove_action('avventura_lite_slick_slider', 'avventura_lite_slick_slider_function');
		remove_action('avventura_lite_top_sidebar', 'avventura_lite_top_sidebar_function');
		remove_action('avventura_lite_thumbnail', 'avventura_lite_thumbnail_function');
		remove_action('post_class', 'avventura_lite_post_class');

	}
	
	add_action('init','sagace_replace_hooks');

}

/*-----------------------------------------------------------------------------------*/
/* Exclude sticky posts on home */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sagace_is_featured_posts_on_archive')) {

	function sagace_is_featured_posts_on_archive() {
		
		if (
			is_author() ||
			is_category() ||
			is_tag() ||
			is_tax('post_format')
		) :
		
			return true;
			
		else :

			return false;

		endif;

	}

}

/*-----------------------------------------------------------------------------------*/
/* Exclude featured posts on homepage */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sagace_exclude_featured_posts_on_home')) {

	function sagace_exclude_featured_posts_on_home(&$query) {
		
		if ( 
			(
				$query->is_home() && 
				$query->is_main_query() &&
				avventura_lite_setting('sagace_featured_area', 'on') == 'on'
			) ||
			( 
				$query->is_archive() &&
				$query->is_main_query() &&
				sagace_is_featured_posts_on_archive() == true &&
				avventura_lite_setting('sagace_featured_area', 'on') == 'on'
			)			
		){ 
	
			$offset = 7;
			
			$ppp = get_option('posts_per_page');
		
			if ( $query->is_paged ) {
				
				$page_offset = $offset + ( ($query->query_vars['paged']-1) * $ppp );
				$query->set('offset', $page_offset );
		
			}
			else {
				$query->set('offset',$offset);
			}
	
		}
	
	}

	add_action('pre_get_posts', 'sagace_exclude_featured_posts_on_home', 1 );

}

/*-----------------------------------------------------------------------------------*/
/* Adjust offset pagination */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sagace_adjust_offset_pagination')) {

	function sagace_adjust_offset_pagination($found_posts, $query) {
	
		$offset = 7;
	
		if ( 
			(
				$query->is_home() && 
				$query->is_main_query() &&
				avventura_lite_setting('sagace_featured_area', 'on') == 'on'
			) ||
			( 
				$query->is_archive() &&
				$query->is_main_query() &&
				sagace_is_featured_posts_on_archive() == true &&
				avventura_lite_setting('sagace_featured_area', 'on') == 'on'
			)			
		){ 
			return $found_posts - $offset;
		}
		
		return $found_posts;
	
	}

	add_filter('found_posts', 'sagace_adjust_offset_pagination', 1, 2 );

}

/*-----------------------------------------------------------------------------------*/
/* Get categories */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sagace_get_categories')) {

	function sagace_get_categories() {

		$args = array(
			'taxonomy' => 'category',
			'hide_empty' => true,
		);

		foreach ( get_terms($args) as $cat) {
			$return[$cat->term_id] = $cat->name;
		}
		
		return $return;

	}

}

/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sagace_customize_register')) {

	function sagace_customize_register( $wp_customize ) {

		$wp_customize->remove_control( 'avventura_lite_header_layout');
		$wp_customize->remove_section( 'slideshow_section');
		$wp_customize->remove_control( 'avventura_lite_home');
		$wp_customize->remove_control( 'avventura_lite_category_layout');
		$wp_customize->remove_control( 'avventura_lite_search_layout');
		$wp_customize->remove_control( 'avventura_lite_post_icon');

		$wp_customize->add_setting( 'sagace_featured_area', array(
			'default' => 'on',
			'sanitize_callback' => 'sagace_select_sanitize',
		));

		$wp_customize->add_control( 'sagace_featured_area' , array(
			'priority' => 9,
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Featured area','sagace'),
			'description' => esc_html__('Do you want to enable the featured area (slideshow and post grid) on homepage and archive pages?','sagace'),
			'choices'  => array (
			   'off' => esc_html__( 'No','sagace'),
			   'on' => esc_html__( 'Yes','sagace'),
			),
		));
		
		$wp_customize->add_panel( 'sagace_postblock_panel', array(
			'title' => esc_html__( 'Sagace Post Blocks', 'sagace' ),
			'description' => esc_html__( 'Sagace Post Block', 'sagace' ),
			'priority' => 13,
		));
		
		$wp_customize->add_section('sagace_postblock_1', array(
			'title' => esc_html__( 'Sagace postBlock 1', 'sagace' ),
			'panel' => 'sagace_postblock_panel',
		));
	
		$wp_customize->add_setting( 'sagace_postblock_1_category', array(
			'default' => 1,
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_1_category' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_1',
			'label' => esc_html__('Category','sagace'),
			'description' => esc_html__('Please select the category of this postblock.','sagace'),
			'choices'  => sagace_get_categories(),
		));
		
		$wp_customize->add_setting( 'sagace_postblock_1_layout', array(
			'default' => 'module-4',
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_1_layout' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_1',
			'label' => esc_html__('Layout','sagace'),
			'description' => esc_html__('Please select the layout of this postblock.','sagace'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','sagace'),
			   'module-1' => esc_html__( 'Module 1','sagace'),
			   'module-2' => esc_html__( 'Module 2','sagace'),
			   'module-3' => esc_html__( 'Module 3','sagace'),
			   'module-4' => esc_html__( 'Module 4','sagace'),
			),
		));

		$wp_customize->add_section('sagace_postblock_2', array(
			'title' => esc_html__( 'Sagace postBlock 2', 'sagace' ),
			'panel' => 'sagace_postblock_panel',
		));
	
		$wp_customize->add_setting( 'sagace_postblock_2_category', array(
			'default' => 1,
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_2_category' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_2',
			'label' => esc_html__('Category','sagace'),
			'description' => esc_html__('Please select the category of this postblock.','sagace'),
			'choices'  => sagace_get_categories(),
		));
		
		$wp_customize->add_setting( 'sagace_postblock_2_layout', array(
			'default' => 'disable',
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_2_layout' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_2',
			'label' => esc_html__('Layout','sagace'),
			'description' => esc_html__('Please select the layout of this postblock.','sagace'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','sagace'),
			   'module-1' => esc_html__( 'Module 1','sagace'),
			   'module-2' => esc_html__( 'Module 2','sagace'),
			   'module-3' => esc_html__( 'Module 3','sagace'),
			   'module-4' => esc_html__( 'Module 4','sagace'),
			),
		));

		$wp_customize->add_section('sagace_postblock_3', array(
			'title' => esc_html__( 'Sagace postBlock 3', 'sagace' ),
			'panel' => 'sagace_postblock_panel',
		));
	
		$wp_customize->add_setting( 'sagace_postblock_3_category', array(
			'default' => 1,
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_3_category' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_3',
			'label' => esc_html__('Category','sagace'),
			'description' => esc_html__('Please select the category of this postblock.','sagace'),
			'choices'  => sagace_get_categories(),
		));
		
		$wp_customize->add_setting( 'sagace_postblock_3_layout', array(
			'default' => 'disable',
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_3_layout' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_3',
			'label' => esc_html__('Layout','sagace'),
			'description' => esc_html__('Please select the layout of this postblock.','sagace'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','sagace'),
			   'module-1' => esc_html__( 'Module 1','sagace'),
			   'module-2' => esc_html__( 'Module 2','sagace'),
			   'module-3' => esc_html__( 'Module 3','sagace'),
			   'module-4' => esc_html__( 'Module 4','sagace'),
			),
		));

		$wp_customize->add_section('sagace_postblock_4', array(
			'title' => esc_html__( 'Sagace postBlock 4', 'sagace' ),
			'panel' => 'sagace_postblock_panel',
		));
	
		$wp_customize->add_setting( 'sagace_postblock_4_category', array(
			'default' => 1,
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_4_category' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_4',
			'label' => esc_html__('Category','sagace'),
			'description' => esc_html__('Please select the category of this postblock.','sagace'),
			'choices'  => sagace_get_categories(),
		));
		
		$wp_customize->add_setting( 'sagace_postblock_4_layout', array(
			'default' => 'disable',
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_postblock_4_layout' , array(
			'type' => 'select',
			'section' => 'sagace_postblock_4',
			'label' => esc_html__('Layout','sagace'),
			'description' => esc_html__('Please select the layout of this postblock.','sagace'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','sagace'),
			   'module-1' => esc_html__( 'Module 1','sagace'),
			   'module-2' => esc_html__( 'Module 2','sagace'),
			   'module-3' => esc_html__( 'Module 3','sagace'),
			   'module-4' => esc_html__( 'Module 4','sagace'),
			),
		));

		$wp_customize->add_section('sagace_post_elements', array(
			'title' => esc_html__( 'Post elements', 'sagace' ),
			'panel' => 'general_panel',
			'description' => esc_html__('From this section you can enable or disable the post elements','sagace'),
			'priority' => '14',
		));
	
		$wp_customize->add_setting( 'sagace_post_category', array(
			'default' => 'on',
			'sanitize_callback' => 'sagace_select_sanitize',
		));

		$wp_customize->add_control( 'sagace_post_category' , array(
			'type' => 'select',
			'section' => 'sagace_post_elements',
			'label' => esc_html__('Categories', 'sagace'),
			'description' => esc_html__('Do you want to display the categories above the post title?', 'sagace'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'sagace'),
				'on' => esc_html__( 'Yes', 'sagace'),
			),
		));
	
		$wp_customize->add_setting( 'sagace_post_date', array(
			'default' => 'on',
			'sanitize_callback' => 'sagace_select_sanitize',
		));

		$wp_customize->add_control( 'sagace_post_date' , array(
			'type' => 'select',
			'section' => 'sagace_post_elements',
			'label' => esc_html__('Post date', 'sagace'),
			'description' => esc_html__('Do you want to display the post date?', 'sagace'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'sagace'),
				'on' => esc_html__( 'Yes', 'sagace'),
			),
		));
	
		$wp_customize->add_setting( 'sagace_post_author', array(
			'default' => 'on',
			'sanitize_callback' => 'sagace_select_sanitize',
		));

		$wp_customize->add_control( 'sagace_post_author' , array(
			'type' => 'select',
			'section' => 'sagace_post_elements',
			'label' => esc_html__('Post author', 'sagace'),
			'description' => esc_html__('Do you want to display the post author?', 'sagace'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'sagace'),
				'on' => esc_html__( 'Yes', 'sagace'),
			),
		));

		$wp_customize->add_control( 'avventura_lite_post_icon' , array(
			'type' => 'select',
			'section' => 'sagace_post_elements',
			'label' => esc_html__('Post icon', 'sagace'),
			'description' => esc_html__('Do you want to display the post icon?', 'sagace'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'sagace'),
				'on' => esc_html__( 'Yes', 'sagace'),
			),
		));
		
		$wp_customize->add_setting( 'sagace_enable_author_box', array(
			'default' => 'on',
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_enable_author_box' , array(
			'type' => 'select',
			'section' => 'sagace_post_elements',
			'label' => esc_html__('Post author info box','sagace'),
			'description' => esc_html__('Do you want to display the post author info box below the content? (Important, the biographical info must be added from the user settings)','sagace'),
			'choices'  => array (
			   'off' => esc_html__( 'No','sagace'),
			   'on' => esc_html__( 'Yes','sagace'),
			),
		));

		$wp_customize->add_setting( 'sagace_enable_related_posts', array(
			'default' => 'on',
			'sanitize_callback' => 'sagace_select_sanitize',

		));

		$wp_customize->add_control( 'sagace_enable_related_posts' , array(
			'type' => 'select',
			'section' => 'sagace_post_elements',
			'label' => esc_html__('Related posts','sagace'),
			'description' => esc_html__('Do you want to display the related posts at the end of each article?','sagace'),
			'choices'  => array (
			   'off' => esc_html__( 'No','sagace'),
			   'on' => esc_html__( 'Yes','sagace'),
			),
		));

		function sagace_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}
		
	}
	
	add_action( 'customize_register', 'sagace_customize_register', 11 );

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sagace_theme_setup')) {

	function sagace_theme_setup() {

		load_child_theme_textdomain( 'sagace', get_stylesheet_directory() . '/languages' );
		
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/main-article.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/small-article.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/hero-article.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-1.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-2.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-3.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-4.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/author-box.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/slick-slider.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/featured-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/featured-area.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/media.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/post-blocks.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/related-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/top-section.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/post-icon.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/before-content.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/after-content.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/sidebars/top-sidebar.php' );

		remove_theme_support( 'custom-logo');

		$defaults = array( 'header-text' => array( 'site-title', 'site-description' ));
		add_theme_support( 'custom-logo', $defaults );

		add_image_size( 'sagace_slideshow_image', 648, 429, TRUE );
		add_image_size( 'sagace_featured_post_image', 226, 212, TRUE );
		add_image_size( 'sagace_hero_image', 274, 275, TRUE );
		add_image_size( 'sagace_small_image', 120, 100, TRUE ); 
		add_image_size( 'sagace_medium_image', 547, 275, TRUE );
		add_image_size( 'sagace_large_image', 651, 370, TRUE );
		 
		if ( !get_theme_mod('avventura_lite_logo_font_size') )
			set_theme_mod( 'avventura_lite_logo_font_size', '60px' );

		if ( !get_theme_mod('avventura_lite_logo_description_top_margin') )
			set_theme_mod( 'avventura_lite_logo_description_top_margin', '25px' );

	}

	add_action( 'after_setup_theme', 'sagace_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Post class */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('sagace_post_class')) {

	function sagace_post_class($classes) {

		if ( !avventura_lite_is_single() ) {

			if ( 
				is_home() ||
				is_archive() ||
				is_search() 
			
			) {

				$classes[] = 'post-container';

			}

		} else if ( avventura_lite_is_single() && avventura_lite_is_woocommerce_active('is_cart') ) {

			$classes[] = 'post-container col-md-12 woocommerce_cart_page';

		} else if ( avventura_lite_is_single() && !avventura_lite_is_woocommerce_active('is_product') ) {

			$classes[] = 'post-container col-md-12';

		} else if ( is_page() ) {

			$classes[] = 'full';

		}

		return $classes;

	}

	add_filter('post_class', 'sagace_post_class');

}

?>